@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: gui.h,v $
-// Revision      : $Revision: 1.6.2.2 $
-// Revision date : $Date: 2007/09/08 18:06:30 $
+// Revision      : $Revision: 1.6.2.4 $
+// Revision date : $Date: 2012/01/08 20:59:06 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -35,14 +35,14 @@
 #endif
 #include <string>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include "support.h"
 
 
 class GUI : public Support {
 
 protected:
-	GladeXML *		xml_;		// interface description using XML/glade-2 file
+/// interface description using XML-GTKBuilder file
+	GtkBuilder      *gtkbuilder_;
 	std::string		filename_;	// name of the interface file
 
 public:
