@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: pop.h,v $
-// Revision      : $Revision: 1.12.2.1 $
-// Revision date : $Date: 2007/09/08 18:06:30 $
+// Revision      : $Revision: 1.12.2.2 $
+// Revision date : $Date: 2008/04/25 22:53:05 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -33,7 +33,7 @@
 #include "mailbox.h"
 #include <set>
 
-#define POP(x)					((Pop *)(x))
+#define POP(x)					(static_cast<Pop *>(x))
 
 /**
  * Mailbox for the POP3 and APOP protocols. This serves only as a base for
