@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
+// Copyright (c) 2000-2011 Nicolas Rougier, 2004-2011 Robert Sowada
 //
 // This program is free software: you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-properties.cc,v $
-// Revision      : $Revision: 1.25.2.1 $
-// Revision date : $Date: 2007/09/08 14:57:59 $
+// Revision      : $Revision: 1.25.2.6 $
+// Revision date : $Date: 2012/01/08 21:00:23 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -61,16 +61,16 @@ extern "C" {
 		PROPERTIES(data)->on_mailbox (widget);
 	}
 
-	void PROPERTIES_on_type_changed (GtkAction *action,
+	void PROPERTIES_on_type_changed (GtkComboBoxText *cbox,
 									 gpointer   data)
 	{
-		PROPERTIES(data)->on_type_changed (action);
+		PROPERTIES(data)->on_type_changed ();
 	}
 
-	void PROPERTIES_on_auth_changed (GtkAction *action,
+	void PROPERTIES_on_auth_changed (GtkComboBoxText *cbox,
 									 gpointer   data)
 	{
-		PROPERTIES(data)->on_auth_changed (action);
+		PROPERTIES(data)->on_auth_changed ();
 	}
 
 	void PROPERTIES_on_browse_address (GtkWidget *widget,
@@ -87,7 +87,7 @@ extern "C" {
 
 }
 
-Properties::Properties (Preferences *preferences) : GUI (GNUBIFF_DATADIR"/properties.glade")
+Properties::Properties (Preferences *preferences) : GUI (GNUBIFF_DATADIR"/properties.ui")
 {
 	preferences_ = preferences;
 	mailbox_ = 0;
@@ -101,8 +101,9 @@ Properties::~Properties (void)
 		hide ();
 		gtk_widget_destroy (widget);
 	}
-	if (GTK_IS_OBJECT (xml_))
-		g_object_unref (xml_);
+    if (gtkbuilder_)
+        g_object_unref (G_OBJECT(gtkbuilder_));
+    gtkbuilder_ = NULL;
 }
 
 gboolean
@@ -118,65 +119,30 @@ Properties::create (gpointer callbackdata)
 	gtk_size_group_add_widget (group_, get ("delay"));
 	gtk_size_group_add_widget (group_, get ("mailbox"));
 
-	// Type menu
-	GtkActionEntry type_entries[] = {
-		{ "Autodetect", GTK_STOCK_DIALOG_QUESTION, _("Autodetect"),     0, "Autodetect type",   G_CALLBACK(PROPERTIES_on_type_changed)},
-		{ "File",       GTK_STOCK_HOME,            _("File or Folder"), 0, "File, Mh, Maildir", G_CALLBACK(PROPERTIES_on_type_changed)},
-		{ "Pop",        GTK_STOCK_NETWORK,         "Pop",               0, "Pop3 or Apop",      G_CALLBACK(PROPERTIES_on_type_changed)},
-		{ "Imap",       GTK_STOCK_NETWORK,         "Imap",              0, "Imap4",             G_CALLBACK(PROPERTIES_on_type_changed)}
-	};
-	static const char *type_ui_description =
-		"<ui>"
-		"  <popup name='Type'>"
-		"    <menuitem action='Autodetect'/>"
-		"    <menuitem action='File'/>"
-		"    <menuitem action='Pop'/>"
-		"    <menuitem action='Imap'/>"
-		"  </popup>"
-		"</ui>";
-	GtkActionGroup *action_group = gtk_action_group_new ("actions");
-	gtk_action_group_add_actions (action_group, type_entries, G_N_ELEMENTS (type_entries), this);
-	type_manager_ = gtk_ui_manager_new ();
-	gtk_ui_manager_insert_action_group (type_manager_, action_group, 0);
-	gtk_ui_manager_add_ui_from_string (type_manager_, type_ui_description, -1, 0);
-	type_menu_ = gtk_option_menu_new ();
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (type_menu_), gtk_ui_manager_get_widget (type_manager_, "/Type"));
-	gtk_container_add (GTK_CONTAINER(get("type_container")), type_menu_);
-	gtk_widget_show (type_menu_);
-
+    // Type menu
+    type_cbox_ = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
+    gtk_combo_box_text_append_text (type_cbox_, _("Autodetect"));
+    gtk_combo_box_text_append_text (type_cbox_, _("File or Folder"));
+    gtk_combo_box_text_append_text (type_cbox_, "Pop");
+    gtk_combo_box_text_append_text (type_cbox_, "Imap");
+	gtk_container_add (GTK_CONTAINER (get("type_container")),
+                       GTK_WIDGET (type_cbox_));
+	gtk_widget_show (GTK_WIDGET (type_cbox_));
+    g_signal_connect (G_OBJECT (type_cbox_), "changed",
+                      G_CALLBACK (PROPERTIES_on_type_changed), this);
 
 	// Authentication menu
-	GtkActionEntry auth_entries[] = {
-		{ "Autodetect",		GTK_STOCK_DIALOG_QUESTION, _("Autodetect"),
-		  0, 0, G_CALLBACK(PROPERTIES_on_auth_changed)},
-		{ "UserPass",		GTK_STOCK_DIALOG_WARNING, _("User/Pass"),
-		  0, 0, G_CALLBACK(PROPERTIES_on_auth_changed)},
-		{ "Apop",			GTK_STOCK_DIALOG_AUTHENTICATION, _("Encrypted User/Pass (apop)"),
-		  0, 0, G_CALLBACK(PROPERTIES_on_auth_changed)},
-		{ "SSL",			GTK_STOCK_DIALOG_AUTHENTICATION, "SSL",
-		  0, 0, G_CALLBACK(PROPERTIES_on_auth_changed)},
-		{ "Certificate",	GTK_STOCK_DIALOG_AUTHENTICATION, _("SSL with certificate"),
-		  0, 0, G_CALLBACK(PROPERTIES_on_auth_changed)}
-	};
-	static const char *auth_ui_description =
-		"<ui>"
-		"  <popup name='Auth'>"
-		"    <menuitem action='Autodetect'/>"
-		"    <menuitem action='UserPass'/>"
-		"    <menuitem action='Apop'/>"
-		"    <menuitem action='SSL'/>"
-		"    <menuitem action='Certificate'/>"
-		"  </popup>"
-		"</ui>";
-	action_group = gtk_action_group_new ("actions");
-	gtk_action_group_add_actions (action_group, auth_entries, G_N_ELEMENTS (auth_entries), this);
-	auth_manager_ = gtk_ui_manager_new ();
-	gtk_ui_manager_insert_action_group (auth_manager_, action_group, 0);
-	gtk_ui_manager_add_ui_from_string (auth_manager_, auth_ui_description, -1, 0);
-	auth_menu_ = gtk_option_menu_new ();
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (auth_menu_), gtk_ui_manager_get_widget (auth_manager_, "/Auth"));
-	gtk_container_add (GTK_CONTAINER(get("auth_container")), auth_menu_);
-	gtk_widget_show (auth_menu_);
+    auth_cbox_ = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
+    gtk_combo_box_text_append_text (auth_cbox_, _("Autodetect"));
+    gtk_combo_box_text_append_text (auth_cbox_, _("User/Pass"));
+    gtk_combo_box_text_append_text (auth_cbox_, _("Encrypted User/Pass (apop)"));
+    gtk_combo_box_text_append_text (auth_cbox_, "SSL");
+    gtk_combo_box_text_append_text (auth_cbox_, _("SSL with certificate"));
+	gtk_container_add (GTK_CONTAINER (get("auth_container")),
+                       GTK_WIDGET (auth_cbox_));
+	gtk_widget_show (GTK_WIDGET (auth_cbox_));
+    g_signal_connect (G_OBJECT (auth_cbox_), "changed",
+                      G_CALLBACK (PROPERTIES_on_auth_changed), this);
 
 	return result;
 }
@@ -236,76 +202,63 @@ Properties::on_mailbox (GtkWidget *widget)
 		gtk_widget_set_sensitive (get("mailbox_entry"), true);
 }
 
-void
-Properties::on_type_changed (GtkAction *action)
+void 
+Properties::on_type_changed (void)
 {
-	std::string type = gtk_action_get_name (action);
+    selected_type_ = gtk_combo_box_get_active (GTK_COMBO_BOX (type_cbox_));
 
-	if (type == "Autodetect") {
-		gtk_widget_set_sensitive (get("browse_address"), true);
-		selected_type_ = TYPE_AUTODETECT;
-		identity_view (false);
-		details_view (false);
-	}
-	else if (type == "File") {
-		gtk_widget_set_sensitive (get("browse_address"), true);
-		selected_type_ = TYPE_LOCAL;
-		identity_view (false);
-		details_view (false);
-	}
-	else if (type == "Pop") {
-		gtk_widget_set_sensitive (get("browse_address"), false);
-		selected_type_ = TYPE_POP;
-		identity_view (true);
-		details_view (true);
-		auth_view (true);
-		connection_view (true);
-		certificate_view (false);
-		mailbox_view (false);
-		delay_view (true);
-	}
-	else if (type == "Imap") {
-		gtk_widget_set_sensitive (get("browse_address"), false);
-		selected_type_ = TYPE_IMAP;
-		identity_view (true);
-		details_view (true);
-		auth_view (true);
-		connection_view (true);
-		certificate_view (false);
-		mailbox_view (true);
-		delay_view (true);
-	}
+    switch (selected_type_) {
+    case TYPE_AUTODETECT:
+ 		gtk_widget_set_sensitive (get ("browse_address"), true);
+ 		identity_view (false);
+ 		details_view (false);
+        break;
+    case TYPE_LOCAL:
+ 		gtk_widget_set_sensitive (get("browse_address"), true);
+ 		identity_view (false);
+ 		details_view (false);
+        break;
+    case TYPE_POP:
+ 		gtk_widget_set_sensitive (get("browse_address"), false);
+ 		identity_view (true);
+ 		details_view (true);
+ 		auth_view (true);
+ 		connection_view (true);
+ 		certificate_view (false);
+ 		mailbox_view (false);
+ 		delay_view (true);
+        break;
+    case TYPE_IMAP:
+ 		gtk_widget_set_sensitive (get("browse_address"), false);
+ 		identity_view (true);
+ 		details_view (true);
+ 		auth_view (true);
+ 		connection_view (true);
+ 		certificate_view (false);
+ 		mailbox_view (true);
+ 		delay_view (true);
+        break;
+    }
 }
 
-void
-Properties::on_auth_changed (GtkAction *action)
+void 
+Properties::on_auth_changed (void)
 {
-	std::string auth = gtk_action_get_name (action);
+    selected_auth_ = gtk_combo_box_get_active (GTK_COMBO_BOX (auth_cbox_));
+
+    switch (selected_auth_) {
+    case AUTH_CERTIFICATE:
+        certificate_view (true);
+        break;
+    case AUTH_APOP:
+    case AUTH_AUTODETECT:
+    case AUTH_SSL:
+    case AUTH_USER_PASS:
+    default:
+        certificate_view (false);
+        break;
+    }
 
-	if (auth == "Autodetect") {
-		selected_auth_ = AUTH_AUTODETECT;
-		certificate_view (false);
-	}
-	else if (auth == "UserPass") {
-		selected_auth_ = AUTH_USER_PASS;
-		certificate_view (false);
-	}
-	else if (auth == "Apop") {
-		selected_auth_ = AUTH_APOP;
-		certificate_view (false);
-	}
-	else if (auth == "SSL") {
-		selected_auth_ = AUTH_SSL;
-		certificate_view (false);
-	}
-	else if (auth == "Certificate") {
-		selected_auth_ = AUTH_CERTIFICATE;
-		certificate_view (true);
-	}
-	else {
-		selected_auth_ = AUTH_AUTODETECT;
-		certificate_view (false);
-	}
 	// Maybe the standard port has changed: Update the displayed connection
 	// details
 	connection_view (true);
@@ -341,7 +294,7 @@ Properties::on_apply (GtkWidget *widget)
 	std::string oldaddress = mailbox_->address ();
 
 	// Retrieve all values of the options from the GUI elements
-	mailbox_->update_gui (OPTSGUI_GET, OPTGRP_MAILBOX, xml_, filename_);
+	mailbox_->update_gui (OPTSGUI_GET, OPTGRP_MAILBOX, gtkbuilder_, filename_);
 
 	mailbox_->authentication (selected_auth_);
 
@@ -452,7 +405,7 @@ Properties::update_view (void)
 
 	// Insert the values of the options into the GUI widgets and update
 	// widget status
-	mailbox_->update_gui (OPTSGUI_UPDATE, OPTGRP_MAILBOX, xml_, filename_);
+	mailbox_->update_gui (OPTSGUI_UPDATE, OPTGRP_MAILBOX, gtkbuilder_, filename_);
 
 	type_view ();
 }
@@ -501,7 +454,7 @@ Properties::type_view (void)
 
 	connection_view (true);
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (type_menu_), selected_type_);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (type_cbox_) ,selected_type_);
 }
 
 void
@@ -525,7 +478,7 @@ void
 Properties::details_view (gboolean visible)
 {
 	if (visible) {
-		if (!GTK_WIDGET_VISIBLE (get("details_expander"))) {
+		if (!gtk_widget_get_visible (get("details_expander"))) {
 			gtk_widget_show (get("details_expander"));
 			gtk_size_group_add_widget (group_, get ("connection"));
 			gtk_size_group_add_widget (group_, get ("authentication"));
@@ -535,7 +488,7 @@ Properties::details_view (gboolean visible)
 		}
 	}
 	else {
-		if (GTK_WIDGET_VISIBLE (get("details_expander"))) {
+		if (gtk_widget_get_visible (get("details_expander"))) {
 			gtk_widget_hide (get("details_expander"));
 			gtk_size_group_remove_widget (group_, get ("connection"));
 			gtk_size_group_remove_widget (group_, get ("authentication"));
@@ -581,22 +534,22 @@ Properties::auth_view (gboolean visible)
 		return;
 	}
 
-#ifdef HAVE_CRYPTO
-	if (selected_type_ == TYPE_POP)
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Apop"), true);
-	else
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Apop"), false);
-#else
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Apop"), false);
-#endif
+// #ifdef HAVE_CRYPTO
+// 	if (selected_type_ == TYPE_POP)
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Apop"), true);
+// 	else
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Apop"), false);
+// #else
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Apop"), false);
+// #endif
 
-#ifdef HAVE_LIBSSL
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/SSL"), true);
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Certificate"), true);
-#else
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/SSL"), false);
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Certificate"), false);
-#endif
+// #ifdef HAVE_LIBSSL
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/SSL"), true);
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Certificate"), true);
+// #else
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/SSL"), false);
+// 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (auth_manager_, "/Auth/Certificate"), false);
+// #endif
 
 	
 	// Get authentication method
@@ -634,7 +587,7 @@ Properties::auth_view (gboolean visible)
 #endif
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (auth_menu_), auth);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (auth_cbox_), auth);
 	certificate_view (auth == AUTH_CERTIFICATE);
 	selected_auth_ = auth;
 }
